==> haskell-setlocale-1.0.0.9-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-setlocale.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 setlocale
version:              1.0.0.9
visibility:           public
id:                   setlocale-1.0.0.9-GbloffBFEmGB4tdjuaGaib
key:                  setlocale-1.0.0.9-GbloffBFEmGB4tdjuaGaib
license:              BSD-3-Clause
copyright:            2014-2019, Sven Bartscher
maintainer:           sven.bartscher@weltraumschlangen.de
author:               Sven Bartscher
homepage:             https://bitbucket.org/IchUndNichtDu/haskell-setlocale
synopsis:             Haskell bindings to setlocale
category:             System
abi:                  d11f8fa7ce6ca50405631edce5134e8d
exposed:              True
exposed-modules:      System.Locale.SetLocale
import-dirs:          /usr/lib/ghc-8.8.3/site-local/setlocale-1.0.0.9
library-dirs:         /usr/lib/ghc-8.8.3/site-local/setlocale-1.0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/setlocale-1.0.0.9
hs-libraries:         HSsetlocale-1.0.0.9-GbloffBFEmGB4tdjuaGaib
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-setlocale/html/setlocale.haddock
haddock-html:         /usr/share/doc/haskell-setlocale/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-setlocale-1.0.0.9-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-setlocale.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 setlocale
version:              1.0.0.9
visibility:           public
id:                   setlocale-1.0.0.9-6vAzJhczv2ULCTO7TLVz9e
key:                  setlocale-1.0.0.9-6vAzJhczv2ULCTO7TLVz9e
license:              BSD-3-Clause
copyright:            2014-2019, Sven Bartscher
maintainer:           sven.bartscher@weltraumschlangen.de
author:               Sven Bartscher
homepage:             https://bitbucket.org/IchUndNichtDu/haskell-setlocale
synopsis:             Haskell bindings to setlocale
category:             System
abi:                  a95dc816bce8be00b436d84519db6734
exposed:              True
exposed-modules:      System.Locale.SetLocale
import-dirs:          /usr/lib/ghc-8.10.1/site-local/setlocale-1.0.0.9
library-dirs:         /usr/lib/ghc-8.10.1/site-local/setlocale-1.0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/setlocale-1.0.0.9
hs-libraries:         HSsetlocale-1.0.0.9-6vAzJhczv2ULCTO7TLVz9e
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-setlocale/html/setlocale.haddock
haddock-html:         /usr/share/doc/haskell-setlocale/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
